@@ -21,15 +21,18 @@ Pygal -  A python svg graph plotting library
 
 """
 
-__version__ = '0.9.22'
+__version__ = '0.10.1'
 
 from pygal.config import Config
 from pygal.graph.bar import Bar
 from pygal.graph.dot import Dot
+from pygal.graph.funnel import Funnel
+from pygal.graph.gauge import Gauge
 from pygal.graph.horizontal import HorizontalBar
 from pygal.graph.horizontal import HorizontalStackedBar
 from pygal.graph.line import Line
 from pygal.graph.pie import Pie
+from pygal.graph.pyramid import Pyramid
 from pygal.graph.radar import Radar
 from pygal.graph.stackedbar import StackedBar
 from pygal.graph.stackedline import StackedLine
@@ -40,10 +43,13 @@ from pygal.graph.xy import XY
 CHARTS = [
     Bar,
     Dot,
+    Funnel,
+    Gauge,
     HorizontalBar,
     HorizontalStackedBar,
     Line,
     Pie,
+    Pyramid,
     Radar,
     StackedBar,
     StackedLine,
