@@ -23,13 +23,14 @@ Base for pygal charts
 
 from __future__ import division
 import io
-from pygal.serie import Serie, Value, PositiveValue
+from pygal.serie import Serie, Value
 from pygal.view import Margin, Box
-from pygal.util import get_text_box, get_texts_box, cut, rad, humanize
+from pygal.util import (
+    get_text_box, get_texts_box, cut, rad, humanize, truncate)
 from pygal.svg import Svg
 from pygal.config import Config
 from pygal.util import cached_property
-from math import sin, cos
+from math import sin, cos, sqrt
 
 
 class BaseGraph(object):
@@ -85,8 +86,15 @@ class BaseGraph(object):
         """Compute graph margins from set texts"""
         if self.show_legend:
             h, w = get_texts_box(
-                cut(self.series, 'title'), self.legend_font_size)
-            self.margin.right += 10 + w + self.legend_box_size
+                map(lambda x: truncate(x, self.truncate_legend or 15),
+                  cut(self.series, 'title')),
+                self.legend_font_size)
+            if self.legend_at_bottom:
+                h_max = max(h, self.legend_box_size)
+                self.margin.bottom += 10 + h_max * round(
+                        sqrt(len(self.series)) - 1) * 1.5 + h_max
+            else:
+                self.margin.right += 10 + w + self.legend_box_size
 
         if self.title:
             h, w = get_text_box(self.title, self.title_font_size)
@@ -95,12 +103,15 @@ class BaseGraph(object):
         if self._x_labels:
             h, w = get_texts_box(
                 cut(self._x_labels), self.label_font_size)
-            self.margin.bottom += 10 + max(
+            self._x_labels_height = 10 + max(
                 w * sin(rad(self.x_label_rotation)), h)
+            self.margin.bottom += self._x_labels_height
             if self.x_label_rotation:
                 self.margin.right = max(
                     w * cos(rad(self.x_label_rotation)),
                     self.margin.right)
+        else:
+            self._x_labels_height = 0
         if self._y_labels:
             h, w = get_texts_box(
                 cut(self._y_labels), self.label_font_size)
@@ -125,10 +136,15 @@ class BaseGraph(object):
         """Getter for the maximum series size"""
         return max([len(serie.values) for serie in self.series])
 
+    @cached_property
+    def _min(self):
+        """Getter for the minimum series value"""
+        return (self.range and self.range[0]) or min(self._values)
+
     @cached_property
     def _max(self):
         """Getter for the maximum series value"""
-        return max(self._values)
+        return (self.range and self.range[1]) or max(self._values)
 
     def _draw(self):
         """Draw all the things"""
@@ -174,7 +190,8 @@ class BaseGraph(object):
     def render(self, is_unicode=False):
         """Render the graph, and return the svg string"""
         self._render()
-        return self.svg.render(is_unicode=is_unicode)
+        return self.svg.render(
+            is_unicode=is_unicode, pretty_print=self.pretty_print)
 
     def render_tree(self):
         """Render the graph, and return lxml tree"""
