@@ -16,9 +16,14 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
+"""
+Charts styling
+"""
+from pygal.util import cycle_fill
 
 
 class Style(object):
+    """Styling class containing colors for the css generation"""
     def __init__(self,
         background='black',
         plot_background='#111',
@@ -33,25 +38,38 @@ class Style(object):
                 '#899ca1', '#f8f8f2', '#808384', '#bf4646', '#516083',
                 '#f92672', '#82b414', '#fd971f', '#56c2d6', '#8c54fe',
                 '#465457')):
-            self.background = background
-            self.plot_background = plot_background
-            self.foreground = foreground
-            self.foreground_light = foreground_light
-            self.foreground_dark = foreground_dark
-            self.opacity = opacity
-            self.opacity_hover = opacity_hover
-            self.transition = transition
-            self._colors = colors
+        self.background = background
+        self.plot_background = plot_background
+        self.foreground = foreground
+        self.foreground_light = foreground_light
+        self.foreground_dark = foreground_dark
+        self.opacity = opacity
+        self.opacity_hover = opacity_hover
+        self.transition = transition
+        self._colors = colors
 
     @property
     def colors(self):
+        """Get the css color list"""
+
         def color(tupl):
+            """Make a color css"""
             return (
                     '.color-{0} {{\n'
                     '  stroke: {1};\n'
                     '  fill: {1};\n'
                     '}}\n'.format(*tupl))
-        return '\n'.join(map(color, enumerate(self._colors)))
+        return '\n'.join(map(color, enumerate(cycle_fill(self._colors, 16))))
+
+    def to_dict(self):
+        config = {}
+        for attr in dir(self):
+            if not attr.startswith('__'):
+                value = getattr(self, attr)
+                if not hasattr(value, '__call__'):
+                    config[attr] = value
+        return config
+
 
 DefaultStyle = Style(opacity_hover='.4', opacity='.8')
 LightStyle = Style(
