@@ -25,6 +25,7 @@ from __future__ import division
 from decimal import Decimal
 from math import floor, pi, log, log10, ceil
 from itertools import cycle
+import re
 ORDERS = u"yzafpnµm kMGTPEZY"
 
 
@@ -175,9 +176,14 @@ def compute_scale(min_, max_, logarithmic=False, min_scale=4, max_scale=20):
     return positions
 
 
-def text_len(lenght, fs):
+def text_len(length, fs):
+    """Approximation of text width"""
+    return length * 0.6 * fs
+
+
+def reverse_text_len(width, fs):
     """Approximation of text length"""
-    return lenght * 0.6 * fs
+    return width / (0.6 * fs)
 
 
 def get_text_box(text, fs):
@@ -212,11 +218,18 @@ def cycle_fill(short_list, max_len):
     """Fill a list to max_len using a cycle of it"""
     short_list = list(short_list)
     list_cycle = cycle(short_list)
-    while len(short_list) < 16:
+    while len(short_list) < max_len:
         short_list.append(list_cycle.next())
     return short_list
 
 
+def truncate(string, index):
+    """Truncate a string at index and add ..."""
+    if len(string) > index and index > 0:
+        string = string[:index - 1] + u'…'
+    return string
+
+
 # Stolen from brownie http://packages.python.org/Brownie/
 class cached_property(object):
     """Optimize a static property"""
@@ -231,3 +244,32 @@ class cached_property(object):
             return self
         value = obj.__dict__[self.__name__] = self.getter(obj)
         return value
+
+css_comments = re.compile(r'/\*.*?\*/', re.MULTILINE | re.DOTALL)
+
+
+def minify_css(css):
+    # Inspired by slimmer by Peter Bengtsson
+    remove_next_comment = 1
+    for css_comment in css_comments.findall(css):
+        if css_comment[-3:] == '\*/':
+            remove_next_comment = 0
+            continue
+        if remove_next_comment:
+            css = css.replace(css_comment, '')
+        else:
+            remove_next_comment = 1
+
+    # >= 2 whitespace becomes one whitespace
+    css = re.sub(r'\s\s+', ' ', css)
+    # no whitespace before end of line
+    css = re.sub(r'\s+\n', '', css)
+    # Remove space before and after certain chars
+    for char in ('{', '}', ':', ';', ','):
+        css = re.sub(char + r'\s', char, css)
+        css = re.sub(r'\s' + char, char, css)
+    css = re.sub(r'}\s(#|\w)', r'}\1', css)
+    # no need for the ; before end of attributes
+    css = re.sub(r';}', r'}', css)
+    css = re.sub(r'}//-->', r'}\n//-->', css)
+    return css.strip()
